diff sat/core/xmpp.py @ 4051:c23cad65ae99

core: renamed `messageReceived` trigger to `message_received`
author Goffi <goffi@goffi.org>
date Mon, 29 May 2023 13:32:08 +0200
parents 524856bd7b19
children
line wrap: on
line diff
--- a/sat/core/xmpp.py	Mon May 15 17:19:54 2023 +0200
+++ b/sat/core/xmpp.py	Mon May 29 13:32:08 2023 +0200
@@ -1319,7 +1319,7 @@
     def _on_message_start_workflow(self, cont, client, message_elt, post_treat):
         """Parse message and do post treatments
 
         It is the first callback called after messageReceived trigger
         @param cont(bool): workflow will continue only if this is True
         @param message_elt(domish.Element): message stanza
             may have be modified by triggers
@@ -1354,7 +1354,7 @@
         post_treat = defer.Deferred()
 
         d = self.host.trigger.async_point(
-            "messageReceived", client, message_elt, post_treat
+            "message_received", client, message_elt, post_treat
         )
 
         d.addCallback(self._on_message_start_workflow, client, message_elt, post_treat)
@@ -1319,7 +1319,7 @@
         """Parse message and do post treatments
 
-        It is the first callback called after messageReceived trigger
+        It is the first callback called after message_received trigger
         @param cont(bool): workflow will continue only if this is True
         @param message_elt(domish.Element): message stanza